@@ -2,6 +2,10 @@
 
 
 from asyncio.futures import Future
+from typing import Dict
+from bergen.messages.postman.provide.provide_done import ProvideDoneMessage
+from functools import partial
+from bergen.messages.postman.provide.bounced_provide import BouncedProvideMessage
 from bergen.entertainer.actor import HostHelper
 from bergen.messages.postman.assign.assign import AssignMessage
 from bergen.messages.base import MessageModel
@@ -10,11 +14,11 @@ from bergen.messages.host import ActivatePodMessage, DeActivatePodMessage
 from bergen.messages.postman.assign import BouncedAssignMessage, BouncedCancelAssignMessage, AssignCriticalMessage, AssignReturnMessage, AssignYieldsMessage, AssignProgressMessage
 from bergen.schema import Pod
 import json
-from bergen.entertainer.base import BaseHost
+from bergen.entertainer.base import BaseEntertainer
 import logging
 import asyncio
 import websockets
-
+from bergen.console import console
 import asyncio
 try:
     from asyncio import create_task
@@ -33,21 +37,21 @@ class WebsocketHelper(HostHelper):
         await self.host.send_to_arkitekt(yield_message)
 
     async def pass_progress(self, message: AssignMessage, value, percentage=None):
-        message = f'{percentage if percentage else "--"} : {value}'
+        value = f'{percentage if percentage else "--"} : {value}'
         progress_message = AssignProgressMessage(data={"message": value, "level": "INFO"}, meta={"extensions": message.meta.extensions, "reference": message.meta.reference})
         await self.host.send_to_arkitekt(progress_message)
-        pass
 
     async def pass_result(self,message: AssignMessage, value):
         return_message = AssignReturnMessage(data={"returns": value}, meta={"extensions": message.meta.extensions, "reference": message.meta.reference})
         await self.host.send_to_arkitekt(return_message)
 
-    async def pass_exception(self,message: AssignMessage, exception):
+    async def pass_exception(self, message: AssignMessage, exception):
         error_message = AssignCriticalMessage(data={"message": str(exception)}, meta={"extensions": message.meta.extensions, "reference": message.meta.reference})
+        print("Sending to arkitekt")
         await self.host.send_to_arkitekt(error_message)
 
 
-class WebsocketHost(BaseHost):
+class WebsocketEntertainer(BaseEntertainer):
     helperClass = WebsocketHelper
     ''' Is a mixin for Our Bergen '''
 
@@ -62,8 +66,6 @@ class WebsocketHost(BaseHost):
         self.allowed_retries = 2
         self.current_retries = 0
 
-        self.all_pod_assignments = {}
-
     async def connect(self):
         self.incoming_queue = asyncio.Queue()
         self.outgoing_queue = asyncio.Queue()
@@ -152,6 +154,9 @@ class WebsocketHost(BaseHost):
 
             self.outgoing_queue.task_done()
 
+    async def forward(self, message: MessageModel):
+        await self.outgoing_queue.put(message)
+
 
     async def send_to_arkitekt(self, message: MessageModel):
         await self.outgoing_queue.put(message)
@@ -166,37 +171,11 @@ class WebsocketHost(BaseHost):
             message_str = await self.incoming_queue.get()
             message = expandToMessage(json.loads(message_str))
             logger.info("Received Assignation")
-
-            if isinstance(message, BouncedAssignMessage):
-                assert message.data.pod is not None, "Received assignation that had no Pod???"
-                assert message.data.pod in self.pod_actor_run_map, f"Pod not entertained {message.data.pod} {self.pod_actor_run_map}"
-                await self.pod_actor_queue_map[message.data.pod].put(message)
-                self.all_pod_assignments[message.meta.reference] = message.data.pod # Run in parallel
-
-            if isinstance(message, BouncedCancelAssignMessage):
-                if message.data.reference in self.all_pod_assignments: 
-                    logger.info("Cancellation for task received. Canceling!")
-                    task = self.assignments[message.data.reference]
-                    if not task.done():
-                        task.cancel()
-                        logger.warn("Canceled Task!!")
-                    else:
-                        logger.warn("Task had already finished")
-                else:
-                    logger.error("Received Cancellation for task that was not in our tasks..")
-
-            
+            await self.on_message(message)
             self.incoming_queue.task_done()
 
 
-    async def deactivatePod(self, id, reference = "spmposmpe"):
-        deactivate = DeActivatePodMessage(data={"pod": id}, meta={"reference": reference})
-        await self.send_to_arkitekt(deactivate)
-        logger.warn(f"Setting Pod inactive {reference}")
-
-    async def activatePod(self, pod: Pod, reference):
-        activate = ActivatePodMessage(data={"pod": pod.id}, meta={"reference": reference})
-        await self.send_to_arkitekt(activate)
+    
 
 
     
