@@ -1,6 +1,6 @@
 import json
 from pydantic import BaseModel
-from typing import Optional, Type, TypeVar
+from typing import Any, Callable, Optional, Type, TypeVar
 
 from pydantic.types import Json
 from pydantic import Field
@@ -14,7 +14,7 @@ class MessageMetaExtensionsModel(BaseModel):
 
 class MessageMetaModel(BaseModel):
     type: str
-    reference: str = Field(default_factory=uuid.uuid4)
+    reference: str = Field(default_factory=lambda x: str(uuid.uuid4))
     extensions: Optional[MessageMetaExtensionsModel] = { }
 
 
@@ -41,4 +41,13 @@ class MessageModel(BaseModel):
     def from_channels(cls: Type[T], message: str) -> T:
         return cls(**json.loads(message))
 
+    @classmethod
+    def unwrapped_message(cls: Type[T], function) -> Callable[[Any], T]:
+
+        async def unwrapped(self, message, *args, **kwargs):
+            print(message)
+            input = cls.from_message(message)
+            return await function(self, input, message, *args, **kwargs)
+
+        return unwrapped
     
