@@ -1,10 +1,9 @@
+from .params import ReserveParams
 from pydantic.main import BaseModel
 from ....messages.types import  RESERVE
 from ....messages.base import MessageDataModel, MessageMetaExtensionsModel, MessageMetaModel, MessageModel
 from typing import List, Optional
 
-class ProvideParams(BaseModel):
-    providers: Optional[List[str]]
 
 
 class ProvideMetaExtensionsModel(MessageMetaExtensionsModel):
@@ -20,7 +19,7 @@ class ProvideDataModel(MessageDataModel):
 
     node: Optional[str] #TODO: Maybe not optional
     template: Optional[str]
-    params: Optional[ProvideParams]
+    params: Optional[ReserveParams]
 
 
 class ReserveMessage(MessageModel):
