@@ -1,9 +1,11 @@
 from .host import DeActivatePodMessage, ActivatePodMessage
-from .postman.assign import AssignMessage, AssignReturnMessage, AssignProgressMessage, AssignCriticalMessage, AssignYieldsMessage, BouncedAssignMessage, BouncedCancelAssignMessage
+from .postman.assign import *
 from .base import MessageModel
 from .types import *
-from .postman.provide import ProvideDoneMessage, ProvideCriticalMessage, ProvideMessage, ProvideProgressMessage, BouncedProvideMessage, BouncedCancelProvideMessage
+from .postman.provide import *
+from .postman.unprovide import *
 from .postman.reserve import *
+from .postman.unreserve import *
 from .exception import ExceptionMessage
 import json
 
@@ -16,17 +18,29 @@ registry = {
     PROVIDE_PROGRESS: ProvideProgressMessage,
     PROVIDE: ProvideMessage,
 
+    UNPROVIDE_DONE:  UnprovideDoneMessage,
+    BOUNCED_UNPROVIDE: BouncedUnprovideMessage,
+    BOUNCED_CANCEL_UNPROVIDE: BouncedCancelUnprovideMessage,
+    UNPROVIDE_CRITICAL: UnprovideCriticalMessage,
+    UNPROVIDE_PROGRESS: UnprovideProgressMessage,
+    UNPROVIDE: UnprovideMessage,
 
     RESERVE: ReserveMessage,
-    UNRESERVE: UnReserveMessage,
     BOUNCED_RESERVE: BouncedReserveMessage,
     BOUNCED_CANCEL_RESERVE: BouncedCancelReserveMessage,
     RESERVE_CRITICAL: ReserveCriticalMessage,
     RESERVE_PROGRESS: ReserveProgressMessage,
     RESERVE_DONE: ReserveDoneMessage,
 
+    UNRESERVE: UnreserveMessage,
+    BOUNCED_UNRESERVE: BouncedUnreserveMessage,
+    BOUNCED_CANCEL_UNRESERVE: BouncedCancelUnreserveMessage,
+    UNRESERVE_CRITICAL: UnreserveCriticalMessage,
+    UNRESERVE_PROGRESS: UnreserveProgressMessage,
+    UNRESERVE_DONE: UnreserveDoneMessage,
 
     ASSIGN: AssignMessage,
+    CANCEL_ASSIGN: CancelAssignMessage,
     ASSIGN_CRITICAL: AssignCriticalMessage,
     ASSIGN_PROGRES: AssignProgressMessage,
     ASSIGN_RETURN: AssignReturnMessage,
