@@ -1,4 +1,3 @@
-from bergen.extenders.pod import PodExtender
 from bergen.types.model import ArnheimModelManager
 from bergen.extenders.user import UserExtender
 from bergen.queries.delayed.node import CREATE_NODE_MUTATION, NODE_FILTER_QUERY, NODE_QUERY, UPDATE_OR_CREATE_NODE
@@ -35,7 +34,7 @@ class Node(NodeExtender, SchemaNode):
 
 
 
-class Pod(PodExtender, SchemaPod):
+class Pod(SchemaPod):
     __slots__ = ("_loop", "_force_sync", "_postman")
 
     objects = NodeManager()
