@@ -1,11 +1,17 @@
 from asyncio.tasks import ensure_future
+from bergen.messages.postman.unprovide.unprovide_progress import UnprovideProgressMessage
+from bergen.messages.postman.unprovide.unprovide_done import UnprovideDoneMessage
+from bergen.messages.postman.unreserve import UnreserveDoneMessage, UnreserveMessage
+from bergen.messages.postman.unprovide import UnprovideMessage
+from bergen.messages.postman.reserve.bounced_reserve import ReserveParams
+from bergen.messages.postman.provide.bounced_provide import ProvideParams
 from bergen.messages.postman.reserve.reserve_done import ReserveDoneMessage
 from bergen.messages.postman.assign.assign_yield import AssignYieldsMessage
 from bergen.messages.postman.assign.assign_critical import AssignCriticalMessage
 from bergen.messages.postman.assign import AssignReturnMessage, AssignProgressMessage, CancelAssignMessage, AssignMessage
 from bergen.messages.utils import expandToMessage
-from bergen.messages.postman.provide import UnProvideMessage, ProvideDoneMessage, ProvideMessage,  ProvideProgressMessage, ProvideCriticalMessage
-from bergen.messages.postman.reserve import ReserveMessage, CancelReserveMessage, UnReserveMessage, ReserveProgressMessage, ReserveCriticalMessage
+from bergen.messages.postman.provide import ProvideDoneMessage, ProvideMessage,  ProvideProgressMessage, ProvideCriticalMessage
+from bergen.messages.postman.reserve import ReserveMessage, CancelReserveMessage, ReserveProgressMessage, ReserveCriticalMessage
 from typing import Callable
 from bergen.utils import expandOutputs, shrinkInputs
 from bergen.messages.exception import ExceptionMessage
@@ -15,7 +21,7 @@ import uuid
 import logging
 from functools import partial
 import json
-
+from bergen.console import console
 import asyncio
 try:
     from asyncio import create_task
@@ -96,7 +102,6 @@ class WebsocketPostman(BasePostman):
     async def disconnect(self):
 
         for task in self.pending:
-            print(task)
             task.cancel()
 
         if self.connection: await self.connection.close()
@@ -159,7 +164,7 @@ class WebsocketPostman(BasePostman):
 
     async def connect_websocket(self):
         self.connection = await websockets.client.connect(self.uri)
-        logger.info("Successfully connected Postman")
+        logger.info("Successfully connected [bold]Postman")
         
 
     async def receiving(self):
@@ -182,15 +187,11 @@ class WebsocketPostman(BasePostman):
             try:
                 parsed_message = expandToMessage(json.loads(message))
                 correlation_id = parsed_message.meta.reference
-                assert correlation_id in self.futures or correlation_id in self.streams , "Received Message that wasn't originaing from our futures or streams"
-               
-                # Stream Path
 
                 if correlation_id in self.streams:
                     # It is a stream delage to stream
                     await self.streams[correlation_id].put(parsed_message)
 
-
                 # Callback Path
                 elif correlation_id in self.futures:
             
@@ -218,6 +219,18 @@ class WebsocketPostman(BasePostman):
                         future = self.futures.pop(correlation_id)
                         future.set_result((parsed_message.meta.reference, parsed_message.data.channel))
 
+                    elif isinstance(parsed_message, UnreserveDoneMessage):
+                        future = self.futures.pop(correlation_id)
+                        future.set_result((parsed_message.meta.reference, parsed_message.data.channel))
+
+                    elif isinstance(parsed_message, UnprovideProgressMessage):
+                        # We omit this as it is part of the unreserving process
+                        pass
+
+                    elif isinstance(parsed_message, UnprovideDoneMessage):
+                        # We omit this as it is part of the unreserving process
+                        pass
+
                     elif isinstance(parsed_message, ProvideCriticalMessage):
                         future = self.futures.pop(correlation_id)
                         future.set_exception(ProviderException(parsed_message.data.message))
@@ -232,10 +245,11 @@ class WebsocketPostman(BasePostman):
 
 
                 else:
-                    raise Exception("Message not in correlation_id", parsed_message )
+                    # We omit this in non debugging mode
+                    pass 
 
             except Exception as e:
-                logger.error(e)
+                console.log(e)
 
             self.callback_queue.task_done()
 
@@ -243,11 +257,8 @@ class WebsocketPostman(BasePostman):
     async def buildAssignMessage(self, reference: str = None, node: Node = None, pod: Pod = None, reservation: str = None, args=None, kwargs = None, params= None, with_progress=False):
         assert reference is not None, "Must have a reference"
 
-        logger.info(args, kwargs)
-        try:
-            args, kwargs = await shrinkInputs(node=node, args=args, kwargs=kwargs)
-        except Exception as e:
-            logger.error(e)
+        args, kwargs = await shrinkInputs(node=node, args=args, kwargs=kwargs)
+        
         assign =  AssignMessage(data={
                                     "node": node.id if node else None, 
                                     "pod": pod.id if pod else None, 
@@ -263,15 +274,13 @@ class WebsocketPostman(BasePostman):
                                         "callback": reference
                                     }
                                 })
-        logger.info(assign)
-        print(assign)
+        
         return assign
 
 
     async def stream(self, node: Node = None, pod: Pod = None, reservation: str = None, args = None, kwargs = None, params= None, on_progress: Callable = None):
-        logger.info(f"Creating a Stream")
+        
         reference = str(uuid.uuid4())
-
         self.streams[reference] = asyncio.Queue()
 
         with_progress = False
@@ -282,25 +291,31 @@ class WebsocketPostman(BasePostman):
         assign = await self.buildAssignMessage(reference=reference, node=node, pod=pod, reservation=reservation, args=args, kwargs=kwargs, params=params, with_progress=with_progress)
         await self.send_to_arkitekt(assign)
 
-        while True:
-            parsed_message = await self.streams[reference].get()
+        try:
+            while True:
+                parsed_message = await self.streams[reference].get()
 
-            if isinstance(parsed_message, ExceptionMessage):
-                raise parsed_message.toException()
+                if isinstance(parsed_message, ExceptionMessage):
+                    raise parsed_message.toException()
 
-            if isinstance(parsed_message, AssignProgressMessage):
-                if on_progress:
-                    asyncio.get_event_loop().call_soon_threadsafe(on_progress(parsed_message.data.message))
+                if isinstance(parsed_message, AssignProgressMessage):
+                    if on_progress:
+                        asyncio.get_event_loop().call_soon_threadsafe(on_progress(parsed_message.data.message))
 
-            if isinstance(parsed_message, AssignYieldsMessage):
-                yield await expandOutputs(node, outputs=parsed_message.data.yields)
+                if isinstance(parsed_message, AssignYieldsMessage):
+                    yield await expandOutputs(node, outputs=parsed_message.data.yields)
 
-            if isinstance(parsed_message, AssignReturnMessage):
-                break
+                if isinstance(parsed_message, AssignReturnMessage):
+                    break
+
+        except asyncio.CancelledError as e:
+            logger.error(e)
+            del self.streams[reference]
 
 
+    async def forward(self, message: MessageModel):
+        await self.send_to_arkitekt(message)
         
-
     async def send_to_arkitekt(self,request: MessageModel):
         await self.send_queue.put(request)
 
@@ -313,17 +328,23 @@ class WebsocketPostman(BasePostman):
         with_progress = False
         if on_progress:
             assert callable(on_progress), "on_progress if provided must be a function/lambda"
-            self.progresses[reference] = lambda progress: logger.info(progress) 
+            self.progresses[reference] = on_progress
             with_progress = True
         
         assign = await self.buildAssignMessage(reference=reference, node=node, pod=pod, reservation=reservation, args=args, kwargs=kwargs, params=params, with_progress=with_progress)
         await self.send_to_arkitekt(assign)
-        logger.warn(assign)
+        
+        try:
+            future.add_done_callback(partial(self.check_if_assign_cancel, reference))  
+            outputs = await future
+            return await expandOutputs(node, outputs)
 
-        future.add_done_callback(partial(self.check_if_assign_cancel, reference))  
-        outputs = await future
+        except asyncio.CancelledError as e:
+            if on_progress: on_progress("[red] Cancelled")
+            cancel = CancelAssignMessage(data={"reference": reference}, meta={"reference": reference})
+            await self.forward(cancel)
+            raise e
 
-        return await expandOutputs(node, outputs)
 
 
     def check_if_assign_cancel(self, reference, future):
@@ -331,10 +352,10 @@ class WebsocketPostman(BasePostman):
         if future.cancelled():
             cancel = CancelAssignMessage(data={reference: reference}, meta={reference: reference})
             self.tasks.append(asyncio.create_task(self.send_to_arkitekt(cancel)))
-            logger.warn(f"Cancelling Assignation {cancel.data.reference}")
+            console.log(f"Cancelling Assignation {cancel.data.reference}")
 
         if future.exception():
-            raise future.exception()
+            pass 
 
     def check_if_provide_cancel(self, reference, future):
         # We cancelled the future and now would like to cancel it also on the Arnheim side
@@ -358,13 +379,13 @@ class WebsocketPostman(BasePostman):
             raise future.exception()
 
 
-    async def buildProvideMessage(self, reference: str = None, node: Node = None, template: Template = None, params= None, with_progress=False):
+    async def buildProvideMessage(self, reference: str = None, node: Node = None, template: Template = None, params: ProvideParams= None, with_progress=False):
         assert reference is not None, "Must have a reference"
 
         return ProvideMessage(data={
                                     "node": node.id if node else None, 
                                     "template": template.id if template else None, 
-                                    "params": dict(params or {}),
+                                    "params": params.dict() if params else {},
                                 },
                                 meta={
                                     "reference": reference,
@@ -375,13 +396,13 @@ class WebsocketPostman(BasePostman):
       
                                 })
 
-    async def buildReserveMessage(self, reference: str = None, node: Node = None, template: Template = None, params= None, with_progress=False):
+    async def buildReserveMessage(self, reference: str = None, node: Node = None, template: Template = None, params: ReserveParams = None, with_progress=False):
         assert reference is not None, "Must have a reference"
 
         return ReserveMessage(data={
                                     "node": node.id if node else None, 
                                     "template": template.id if template else None, 
-                                    "params": dict(params or {}),
+                                    "params": params.dict() if params else None,
                                 },
                                 meta={
                                     "reference": reference,
@@ -397,7 +418,7 @@ class WebsocketPostman(BasePostman):
     async def buildUnProvideMessage(self, reference: str = None, pod: Pod = None,  with_progress=False):
         assert pod is not None, "Must have a pod to unprovide"
 
-        return UnProvideMessage(data={
+        return UnprovideMessage(data={
                                     "pod": pod.id , 
                                 },
                                 meta={
@@ -410,11 +431,11 @@ class WebsocketPostman(BasePostman):
                                 })
 
 
-    async def buildUnReserveMessage(self, reference: str = None, reservation: str = None,  with_progress=False):
-        assert reservation is not None, "Must have a reservation to unreserve"
+    async def buildUnReserveMessage(self, reference: str = None, reservation_reference: str = None,  with_progress=False):
+        assert reservation_reference is not None, "Must have a reservation to unreserve"
 
-        return UnReserveMessage(data={
-                                    "reservation": reservation , 
+        return UnreserveMessage(data={
+                                    "reference": reservation_reference, 
                                 },
                                 meta={
                                     "reference": reference,
@@ -444,7 +465,7 @@ class WebsocketPostman(BasePostman):
         return result
 
 
-    async def provide(self, node: Node = None, template: Template = None , params= None, on_progress: Callable = None) -> Pod:
+    async def provide(self, node: Node = None, template: Template = None , params: ProvideParams = None, on_progress: Callable = None) -> Pod:
         reference = str(uuid.uuid4()) 
         # Where should we do this?
         future = self.loop.create_future()
@@ -486,8 +507,7 @@ class WebsocketPostman(BasePostman):
         return reservation_id
 
     async def unreserve(self, reservation: str= None, on_progress: Callable = None) -> Pod:
-        reference = str(uuid.uuid4()) 
-        # Where should we do this?
+        reference = str(uuid.uuid4())
         future = self.loop.create_future()
         self.futures[reference] = future
 
@@ -497,16 +517,14 @@ class WebsocketPostman(BasePostman):
             self.progresses[reference] = lambda progress: logger.info(progress) 
             with_progress = True
         
-        assign = await self.buildUnReserveMessage(reference=reference, reservation=reservation, with_progress=with_progress)
+        assign = await self.buildUnReserveMessage(reference=reference, reservation_reference=reservation, with_progress=with_progress)
         await self.send_to_arkitekt(assign)
         result = await future
         return result
 
 
-    async def reserve_stream(self, node: Node = None, template: Template = None , params= None, on_progress: Callable = None):
-        logger.info(f"Creating a Reservation Stream")
+    async def reserve_stream(self, node: Node = None, template: Template = None , params: ReserveParams= None, on_progress: Callable = None):
         reference = str(uuid.uuid4())
-
         self.streams[reference] = asyncio.Queue()
 
         with_progress = False
@@ -517,6 +535,12 @@ class WebsocketPostman(BasePostman):
         assign = await self.buildReserveMessage(reference=reference, node=node, template=template, params=params, with_progress=with_progress)
         await self.send_to_arkitekt(assign)
 
-        while True:
-            parsed_message = await self.streams[reference].get()
-            yield parsed_message
\ No newline at end of file
+        try:
+            while True:
+                parsed_message = await self.streams[reference].get()
+                yield parsed_message
+
+        except asyncio.CancelledError as e:
+            # Otherwise we will still listen to the stream on cancellation
+            del self.streams[reference]
+            raise e # Otherwise we raise it further and further
\ No newline at end of file
