@@ -2,10 +2,17 @@
 
 from abc import ABC, abstractmethod
 from asyncio.events import AbstractEventLoop
+from bergen.messages.postman.unprovide.unprovide_critical import UnprovideCriticalMessage
+from bergen.messages.postman.unprovide.unprovide_progress import UnprovideProgressMessage
+from bergen.messages.postman.provide.provide_critical import ProvideCriticalMessage
+from bergen.messages.postman.unprovide import BouncedUnprovideMessage, UnprovideDoneMessage
+from bergen.clients.base import BaseBergen
+from bergen.messages.base import MessageModel
+from bergen.hookable.base import Hookable, hookable
 from bergen.entertainer.actor import Actor, AsyncFuncActor, AsyncGenActor, ThreadedFuncActor
 from bergen.messages.postman.assign.assign import AssignMessage
 from bergen.provider.utils import createNodeFromActor, createNodeFromFunction
-
+from bergen.console import console
 from pydantic.main import BaseModel
 from bergen.types.node import ports
 from typing import Dict, Tuple, TypedDict, Union
@@ -27,7 +34,7 @@ import copy
 import json
 from bergen.types.model import ArnheimModel
 import uuid
-
+from bergen.messages.postman.provide import BouncedProvideMessage, ProvideProgressMessage, BouncedCancelProvideMessage
 
 
 class BaseHelper(ABC):
@@ -148,15 +155,15 @@ def isactor(type):
 
 
 
-class BaseProvider:
+class BaseProvider(Hookable):
     ''' Is a mixin for Our Bergen '''
     helperClass = None
 
 
-    def __init__(self, *args, name = None, provider: int = None, loop=None, client=None) -> None:
+    def __init__(self, *args, provider: int = None, loop=None, client: BaseBergen =None, **kwargs) -> None:
+        super().__init__(**kwargs)
         assert provider is not None, "Provider was set to none, this is weird!!"
         self.arkitekt_provider = provider
-        self.name = name
         self.client = client
         self.loop = loop or asyncio.get_event_loop()
 
@@ -211,18 +218,17 @@ class BaseProvider:
             allow_empty_doc (bool, optional): Allow the enabled function to not have a documentation. Will automatically downlevel the Node Defaults to False.
             widgets (dict, optional): Enable special widgets for the parameters. Defaults to {}.
         """
-
-
-        assert self.name is not None, "We have no name provided, cannot put created Nodes in a Package without a"
         def real_decorator(function_or_actor):
             assert callable(function_or_actor) or issubclass(function_or_actor, Actor), "Please only decorate functions or subclasses of Actor"
 
             if isactor(function_or_actor):
-                logger.info("Already is Actor. Creating Node")
-                node = createNodeFromActor(function_or_actor, self.name, allow_empty_doc=allow_empty_doc, widgets=widgets)
+                console.log("Already is Actor. Creating Node")
+                node = createNodeFromActor(function_or_actor, allow_empty_doc=allow_empty_doc, widgets=widgets)
             else:
-                logger.info("Is Function. Creating Node and Wrapping")
-                node = createNodeFromFunction(function_or_actor, self.name, allow_empty_doc=allow_empty_doc, widgets=widgets)
+                console.log("Is Function. Creating Node and Wrapping")
+                node = createNodeFromFunction(function_or_actor, allow_empty_doc=allow_empty_doc, widgets=widgets)
+
+            console.log("Created Node",node)
                 
             # We pass this down to our truly template wrapper that takes the node and transforms it
             template_wrapper = self.template(node, **implementation_details)
@@ -240,19 +246,88 @@ class BaseProvider:
     async def disconnect(self) -> str:
         raise NotImplementedError("Please overwrite")
 
+
+    @abstractmethod
+    async def forward(self, message: MessageModel) -> None:
+        raise NotImplementedError("Please overwrite")
+
+
+    async def on_message(self, message: MessageModel):
+        if isinstance(message, BouncedProvideMessage):
+            logger.info("Received Provide Request")
+            assert message.data.template is not None, "Received Provision that had no Template???"
+            await self.handle_bounced_provide(message)
+
+        elif isinstance(message, BouncedUnprovideMessage):
+            logger.info("Received Unprovide Request")
+            assert message.data.provision is not None, "Received Unprovision that had no Provision???"
+            await self.handle_bounced_unprovide(message)
+
+        else: 
+            raise Exception("Received Unknown Task")
+
+
+    async def handle_bounced_provide(self, message: BouncedProvideMessage):
+        try:
+            await self.on_bounced_provide(message)
+
+            progress = ProvideProgressMessage(data={
+            "level": "INFO",
+            "message": f"Pod Pending"
+            }, meta={"extensions": message.meta.extensions, "reference": message.meta.reference})
+
+            await self.forward(progress)
+        except Exception as e:
+            logger.error(e)
+            critical_error = ProvideCriticalMessage(data={
+            "message": str(e)
+            }, meta={"extensions": message.meta.extensions, "reference": message.meta.reference})
+            await self.forward(critical_error)
+            raise e
+
+    async def handle_bounced_unprovide(self, message: BouncedProvideMessage):
+        try:
+            await self.on_bounced_unprovide(message)
+
+            progress = UnprovideProgressMessage(data={
+            "level": "INFO",
+            "message": f"Pod Unproviding"
+            }, meta={"extensions": message.meta.extensions, "reference": message.meta.reference})
+
+            await self.forward(progress)
+
+        except Exception as e:
+            logger.error(e)
+            critical_error = UnprovideCriticalMessage(data={
+            "message": str(e)
+            }, meta={"extensions": message.meta.extensions, "reference": message.meta.reference})
+
+            await self.forward(critical_error)
+
+
+    @hookable("bounced_provide", overwritable=True)
+    async def on_bounced_provide(self, message: BouncedProvideMessage):
+        pod, task = await self.provideTemplate(message, message.data.template)
+        self.provisions[message.meta.reference] = task # Run in parallel
+
+    @hookable("bounced_unprovide", overwritable=True)
+    async def on_bounced_unprovide(self, message: BouncedUnprovideMessage):
+        logger.error("Overwrite me")
+
+
     
-    async def provideTemplate(self, reference: str, template_id: str):
+    async def provideTemplate(self, message, template_id: str):
         assert template_id in self.template_actorClass_map, f"There is no function registered for this template {template_id} not it {self.template_actorClass_map.keys()}"
             
-        actor = self.template_actorClass_map[template_id]
-        pod = await ACCEPT_GQL.run_async(ward=self.client.main_ward, variables= {"template": template_id, "provision": reference})
-        print(f"Created {pod}")
-        await self.client.entertainer.entertain(pod, actor)
-        return pod
+        actorClass = self.template_actorClass_map[template_id]
+        self.client.entertainer.registerActor(template_id, actorClass)
+        return await self.client.entertainer.entertain(message)
+
 
 
     async def provide_async(self):
-        await self.setup_and_run()
+        while True:
+            await asyncio.sleep(3)
 
     def provide(self):
         if self.loop.is_running():
