@@ -60,6 +60,8 @@ OUTPUTS_FR = """
 
 DETAIL_NODE_FR = """
   name
+  package
+  interface
   id
 """ + INPUTS_FR + OUTPUTS_FR 
 
@@ -68,6 +70,8 @@ NODE_QUERY = DelayedGQL("""
 query Node($id: ID, $package: String, $interface: String){
   node(id: $id, package: $package, interface: $interface){
     id
+    package
+    interface
     name
     image
 """ + INPUTS_FR + """
@@ -112,11 +116,13 @@ CREATE_NODE_MUTATION = DelayedGQL("""
 
 
 UPDATE_OR_CREATE_NODE = DelayedGQL("""
-  mutation CreateNodeMutation($description: String!, $args: [ArgPortInput]!, $kwargs: [KwargPortInput]!, $returns: [ReturnPortInput]!, $package: String!, $interface: String!, $name: String!, $type: NodeTypeInput){
-  createNode(description: $description, args: $args, kwargs: $kwargs, returns: $returns, package:$package, interface: $interface, name: $name, type: $type){
+  mutation CreateNodeMutation($description: String!, $args: [ArgPortInput]!, $kwargs: [KwargPortInput]!, $returns: [ReturnPortInput]!, $interface: String!, $name: String!, $type: NodeTypeInput){
+  createNode(description: $description, args: $args, kwargs: $kwargs, returns: $returns, interface: $interface, name: $name, type: $type){
     id
     name
     image
+    package
+    interface
 """ + INPUTS_FR + """
 """ + OUTPUTS_FR + """
   }
